toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  if (this == HB_BUFFER_CLUSTER_LEVEL_MONOTONE_GRAPHEMES)
    return "hb_buffer_cluster_level_t.HB_BUFFER_CLUSTER_LEVEL_MONOTONE_GRAPHEMES, hb_buffer_cluster_level_t.HB_BUFFER_CLUSTER_LEVEL_DEFAULT";
  return super.toString();
}