hb_buffer_message_func_t typedef

hb_buffer_message_func_t: @buffer: An #hb_buffer_t to work upon @font: The #hb_font_t the @buffer is shaped with @message: NULL-terminated message passed to the function @user_data: User data pointer passed by the caller

A callback method for #hb_buffer_t. The method gets called with the #hb_buffer_t it was set on, the #hb_font_t the buffer is shaped with and a message describing what step of the shaping process will be performed. Returning false from this method will skip this shaping step and move to the next one.

Return value: true to perform the shaping step, false to skip it.

Since: 1.1.3

Implementation

typedef hb_buffer_message_func_t =
    ffi.Pointer<ffi.NativeFunction<hb_buffer_message_func_tFunction>>;