hb_direction_t enum

hb_direction_t: @HB_DIRECTION_INVALID: Initial, unset direction. @HB_DIRECTION_LTR: Text is set horizontally from left to right. @HB_DIRECTION_RTL: Text is set horizontally from right to left. @HB_DIRECTION_TTB: Text is set vertically from top to bottom. @HB_DIRECTION_BTT: Text is set vertically from bottom to top.

The direction of a text segment or buffer.

A segment can also be tested for horizontal or vertical orientation (irrespective of specific direction) with HB_DIRECTION_IS_HORIZONTAL() or HB_DIRECTION_IS_VERTICAL().

Inheritance
Available extensions

Values

HB_DIRECTION_INVALID → const hb_direction_t
const hb_direction_t(0)
HB_DIRECTION_LTR → const hb_direction_t
const hb_direction_t(4)
HB_DIRECTION_RTL → const hb_direction_t
const hb_direction_t(5)
HB_DIRECTION_TTB → const hb_direction_t
const hb_direction_t(6)
HB_DIRECTION_BTT → const hb_direction_t
const hb_direction_t(7)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) hb_direction_t

Constants

values → const List<hb_direction_t>
A constant List of the values in this enum, in order of their declaration.