hb_feature_t class final

hb_feature_t: @tag: The #hb_tag_t tag of the feature @value: The value of the feature. 0 disables the feature, non-zero (usually

  1. enables the feature. For features implemented as lookup type 3 (like 'salt') the @value is a one based index into the alternates. @start: the cluster to start applying this feature setting (inclusive). @end: the cluster to end applying this feature setting (exclusive).

The #hb_feature_t is the structure that holds information about requested feature application. The feature will be applied with the given value to all glyphs which are in clusters between @start (inclusive) and @end (exclusive). Setting start to #HB_FEATURE_GLOBAL_START and end to #HB_FEATURE_GLOBAL_END specifies that the feature always applies to the entire buffer.

Inheritance

Constructors

hb_feature_t()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited