hb_memory_mode_t enum

hb_memory_mode_t: @HB_MEMORY_MODE_DUPLICATE: HarfBuzz immediately makes a copy of the data. @HB_MEMORY_MODE_READONLY: HarfBuzz client will never modify the data, and HarfBuzz will never modify the data. @HB_MEMORY_MODE_WRITABLE: HarfBuzz client made a copy of the data solely for HarfBuzz, so HarfBuzz may modify the data. @HB_MEMORY_MODE_READONLY_MAY_MAKE_WRITABLE: See above

Data type holding the memory modes available to client programs.

Regarding these various memory-modes:

  • In no case shall the HarfBuzz client modify memory that is passed to HarfBuzz in a blob. If there is any such possibility, @HB_MEMORY_MODE_DUPLICATE should be used such that HarfBuzz makes a copy immediately,

  • Use @HB_MEMORY_MODE_READONLY otherwise, unless you really really really know what you are doing,

  • @HB_MEMORY_MODE_WRITABLE is appropriate if you really made a copy of data solely for the purpose of passing to HarfBuzz and doing that just once (no reuse!),

  • If the font is mmap()ed, it's okay to use @HB_MEMORY_MODE_READONLY_MAY_MAKE_WRITABLE, however, using that mode correctly is very tricky. Use @HB_MEMORY_MODE_READONLY instead.

Inheritance
Available extensions

Values

HB_MEMORY_MODE_DUPLICATE → const hb_memory_mode_t
const hb_memory_mode_t(0)
HB_MEMORY_MODE_READONLY → const hb_memory_mode_t
const hb_memory_mode_t(1)
HB_MEMORY_MODE_WRITABLE → const hb_memory_mode_t
const hb_memory_mode_t(2)
HB_MEMORY_MODE_READONLY_MAY_MAKE_WRITABLE → const hb_memory_mode_t
const hb_memory_mode_t(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) hb_memory_mode_t

Constants

values → const List<hb_memory_mode_t>
A constant List of the values in this enum, in order of their declaration.