hb_segment_properties_t class final

hb_segment_properties_t: @direction: the #hb_direction_t of the buffer, see hb_buffer_set_direction(). @script: the #hb_script_t of the buffer, see hb_buffer_set_script(). @language: the #hb_language_t of the buffer, see hb_buffer_set_language().

The structure that holds various text properties of an #hb_buffer_t. Can be set and retrieved using hb_buffer_set_segment_properties() and hb_buffer_get_segment_properties(), respectively.

Inheritance

Constructors

hb_segment_properties_t()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited