hb_subset_flags_t enum

hb_subset_flags_t: @HB_SUBSET_FLAGS_DEFAULT: all flags at their default value of false. @HB_SUBSET_FLAGS_NO_HINTING: If set hinting instructions will be dropped in the produced subset. Otherwise hinting instructions will be retained. @HB_SUBSET_FLAGS_RETAIN_GIDS: If set glyph indices will not be modified in the produced subset. If glyphs are dropped their indices will be retained as an empty glyph. @HB_SUBSET_FLAGS_DESUBROUTINIZE: If set and subsetting a CFF font the subsetter will attempt to remove subroutines from the CFF glyphs. @HB_SUBSET_FLAGS_NAME_LEGACY: If set non-unicode name records will be retained in the subset. @HB_SUBSET_FLAGS_SET_OVERLAPS_FLAG: If set the subsetter will set the OVERLAP_SIMPLE flag on each simple glyph. @HB_SUBSET_FLAGS_PASSTHROUGH_UNRECOGNIZED: If set the subsetter will not drop unrecognized tables and instead pass them through untouched. @HB_SUBSET_FLAGS_NOTDEF_OUTLINE: If set the notdef glyph outline will be retained in the final subset. @HB_SUBSET_FLAGS_GLYPH_NAMES: If set the PS glyph names will be retained in the final subset. @HB_SUBSET_FLAGS_NO_PRUNE_UNICODE_RANGES: If set then the unicode ranges in OS/2 will not be recalculated. @HB_SUBSET_FLAGS_NO_LAYOUT_CLOSURE: If set do not perform glyph closure on layout substitution rules (GSUB). Since: 7.2.0. @HB_SUBSET_FLAGS_OPTIMIZE_IUP_DELTAS: If set perform IUP delta optimization on the remaining gvar table's deltas. Since: 8.5.0 @HB_SUBSET_FLAGS_NO_BIDI_CLOSURE: If set do not pull mirrored versions of input codepoints into the subset. Since: 11.1.0 @HB_SUBSET_FLAGS_IFTB_REQUIREMENTS: If set enforce requirements on the output subset to allow it to be used with incremental font transfer IFTB patches. Primarily, this forces all outline data to use long (32 bit) offsets. Since: EXPERIMENTAL @HB_SUBSET_FLAGS_RETAIN_NUM_GLYPHS: If this flag is set along side HB_SUBSET_FLAGS_RETAIN_GIDS then the number of glyphs in the font won't be reduced as a result of subsetting. If necessary empty glyphs will be included at the end of the font to keep the number of glyphs unchanged. @HB_SUBSET_FLAGS_DOWNGRADE_CFF2: If set and instantiating a variable font, convert the output CFF2 table to CFF1. This enables compatibility with older renderers that don't support CFF2. Since: 13.0.0

List of boolean properties that can be configured on the subset input.

Since: 2.9.0

Inheritance
Available extensions

Values

HB_SUBSET_FLAGS_DEFAULT → const hb_subset_flags_t
const hb_subset_flags_t(0)
HB_SUBSET_FLAGS_NO_HINTING → const hb_subset_flags_t
const hb_subset_flags_t(1)
HB_SUBSET_FLAGS_RETAIN_GIDS → const hb_subset_flags_t
const hb_subset_flags_t(2)
HB_SUBSET_FLAGS_DESUBROUTINIZE → const hb_subset_flags_t
const hb_subset_flags_t(4)
HB_SUBSET_FLAGS_NAME_LEGACY → const hb_subset_flags_t
const hb_subset_flags_t(8)
HB_SUBSET_FLAGS_SET_OVERLAPS_FLAG → const hb_subset_flags_t
const hb_subset_flags_t(16)
HB_SUBSET_FLAGS_PASSTHROUGH_UNRECOGNIZED → const hb_subset_flags_t
const hb_subset_flags_t(32)
HB_SUBSET_FLAGS_NOTDEF_OUTLINE → const hb_subset_flags_t
const hb_subset_flags_t(64)
HB_SUBSET_FLAGS_GLYPH_NAMES → const hb_subset_flags_t
const hb_subset_flags_t(128)
HB_SUBSET_FLAGS_NO_PRUNE_UNICODE_RANGES → const hb_subset_flags_t
const hb_subset_flags_t(256)
HB_SUBSET_FLAGS_NO_LAYOUT_CLOSURE → const hb_subset_flags_t
const hb_subset_flags_t(512)
HB_SUBSET_FLAGS_OPTIMIZE_IUP_DELTAS → const hb_subset_flags_t
const hb_subset_flags_t(1024)
HB_SUBSET_FLAGS_NO_BIDI_CLOSURE → const hb_subset_flags_t
const hb_subset_flags_t(2048)
HB_SUBSET_FLAGS_DOWNGRADE_CFF2 → const hb_subset_flags_t
const hb_subset_flags_t(16384)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) hb_subset_flags_t

Constants

values → const List<hb_subset_flags_t>
A constant List of the values in this enum, in order of their declaration.