hb_buffer_diff_flags_t enum
hb_buffer_diff_flags_t:
@HB_BUFFER_DIFF_FLAG_EQUAL: equal buffers.
@HB_BUFFER_DIFF_FLAG_CONTENT_TYPE_MISMATCH: buffers with different
#hb_buffer_content_type_t.
@HB_BUFFER_DIFF_FLAG_LENGTH_MISMATCH: buffers with differing length.
@HB_BUFFER_DIFF_FLAG_NOTDEF_PRESENT: .notdef glyph is present in the
reference buffer.
@HB_BUFFER_DIFF_FLAG_DOTTED_CIRCLE_PRESENT: dotted circle glyph is present
in the reference buffer.
@HB_BUFFER_DIFF_FLAG_CODEPOINT_MISMATCH: difference in #hb_glyph_info_t.codepoint
@HB_BUFFER_DIFF_FLAG_CLUSTER_MISMATCH: difference in #hb_glyph_info_t.cluster
@HB_BUFFER_DIFF_FLAG_GLYPH_FLAGS_MISMATCH: difference in #hb_glyph_flags_t.
@HB_BUFFER_DIFF_FLAG_POSITION_MISMATCH: difference in #hb_glyph_position_t.
Flags from comparing two #hb_buffer_t's.
Buffer with different #hb_buffer_content_type_t cannot be meaningfully compared in any further detail.
For buffers with differing length, the per-glyph comparison is not
attempted, though we do still scan reference buffer for dotted circle and
.notdef glyphs.
If the buffers have the same length, we compare them glyph-by-glyph and report which aspect(s) of the glyph info/position are different.
Since: 1.5.0
Values
- HB_BUFFER_DIFF_FLAG_EQUAL → const hb_buffer_diff_flags_t
-
const hb_buffer_diff_flags_t(0) - HB_BUFFER_DIFF_FLAG_CONTENT_TYPE_MISMATCH → const hb_buffer_diff_flags_t
-
Buffers with different content_type cannot be meaningfully compared in any further detail.
const hb_buffer_diff_flags_t(1) - HB_BUFFER_DIFF_FLAG_LENGTH_MISMATCH → const hb_buffer_diff_flags_t
-
For buffers with differing length, the per-glyph comparison is not attempted, though we do still scan reference for dottedcircle / .notdef glyphs.
const hb_buffer_diff_flags_t(2) - HB_BUFFER_DIFF_FLAG_NOTDEF_PRESENT → const hb_buffer_diff_flags_t
-
We want to know if dottedcircle / .notdef glyphs are present in the reference, as we may not care so much about other differences in this case.
const hb_buffer_diff_flags_t(4) - HB_BUFFER_DIFF_FLAG_DOTTED_CIRCLE_PRESENT → const hb_buffer_diff_flags_t
-
const hb_buffer_diff_flags_t(8) - HB_BUFFER_DIFF_FLAG_CODEPOINT_MISMATCH → const hb_buffer_diff_flags_t
-
If the buffers have the same length, we compare them glyph-by-glyph and report which aspect(s) of the glyph info/position are different.
const hb_buffer_diff_flags_t(16) - HB_BUFFER_DIFF_FLAG_CLUSTER_MISMATCH → const hb_buffer_diff_flags_t
-
const hb_buffer_diff_flags_t(32) - HB_BUFFER_DIFF_FLAG_GLYPH_FLAGS_MISMATCH → const hb_buffer_diff_flags_t
-
const hb_buffer_diff_flags_t(64) - HB_BUFFER_DIFF_FLAG_POSITION_MISMATCH → const hb_buffer_diff_flags_t
-
const hb_buffer_diff_flags_t(128)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → hb_buffer_diff_flags_t
Constants
-
values
→ const List<
hb_buffer_diff_flags_t> - A constant List of the values in this enum, in order of their declaration.