hb_buffer_flags_t enum
hb_buffer_flags_t: @HB_BUFFER_FLAG_DEFAULT: the default buffer flag. @HB_BUFFER_FLAG_BOT: flag indicating that special handling of the beginning of text paragraph can be applied to this buffer. Should usually be set, unless you are passing to the buffer only part of the text without the full context. @HB_BUFFER_FLAG_EOT: flag indicating that special handling of the end of text paragraph can be applied to this buffer, similar to @HB_BUFFER_FLAG_BOT. @HB_BUFFER_FLAG_PRESERVE_DEFAULT_IGNORABLES: flag indication that character with Default_Ignorable Unicode property should use the corresponding glyph from the font, instead of hiding them (done by replacing them with the space glyph and zeroing the advance width.) This flag takes precedence over @HB_BUFFER_FLAG_REMOVE_DEFAULT_IGNORABLES. @HB_BUFFER_FLAG_REMOVE_DEFAULT_IGNORABLES: flag indication that character with Default_Ignorable Unicode property should be removed from glyph string instead of hiding them (done by replacing them with the space glyph and zeroing the advance width.) @HB_BUFFER_FLAG_PRESERVE_DEFAULT_IGNORABLES takes precedence over this flag. Since: 1.8.0 @HB_BUFFER_FLAG_DO_NOT_INSERT_DOTTED_CIRCLE: flag indicating that a dotted circle should not be inserted in the rendering of incorrect character sequences (such at <0905 093E>). Since: 2.4.0 @HB_BUFFER_FLAG_VERIFY: flag indicating that the hb_shape() call and its variants should perform various verification processes on the results of the shaping operation on the buffer. If the verification fails, then either a buffer message is sent, if a message handler is installed on the buffer, or a message is written to standard error. In either case, the shaping result might be modified to show the failed output. Since: 3.4.0 @HB_BUFFER_FLAG_PRODUCE_UNSAFE_TO_CONCAT: flag indicating that the @HB_GLYPH_FLAG_UNSAFE_TO_CONCAT glyph-flag should be produced by the shaper. By default it will not be produced since it incurs a cost. Since: 4.0.0 @HB_BUFFER_FLAG_PRODUCE_SAFE_TO_INSERT_TATWEEL: flag indicating that the @HB_GLYPH_FLAG_SAFE_TO_INSERT_TATWEEL glyph-flag should be produced by the shaper. By default it will not be produced. Since: 5.1.0 @HB_BUFFER_FLAG_DEFINED: All currently defined flags: Since: 4.4.0
Flags for #hb_buffer_t.
Since: 0.9.20
Values
- HB_BUFFER_FLAG_DEFAULT → const hb_buffer_flags_t
-
const hb_buffer_flags_t(0) - HB_BUFFER_FLAG_BOT → const hb_buffer_flags_t
-
Beginning-of-text
const hb_buffer_flags_t(1) - HB_BUFFER_FLAG_EOT → const hb_buffer_flags_t
-
End-of-text
const hb_buffer_flags_t(2) - HB_BUFFER_FLAG_PRESERVE_DEFAULT_IGNORABLES → const hb_buffer_flags_t
-
const hb_buffer_flags_t(4) - HB_BUFFER_FLAG_REMOVE_DEFAULT_IGNORABLES → const hb_buffer_flags_t
-
const hb_buffer_flags_t(8) - HB_BUFFER_FLAG_DO_NOT_INSERT_DOTTED_CIRCLE → const hb_buffer_flags_t
-
const hb_buffer_flags_t(16) - HB_BUFFER_FLAG_VERIFY → const hb_buffer_flags_t
-
const hb_buffer_flags_t(32) - HB_BUFFER_FLAG_PRODUCE_UNSAFE_TO_CONCAT → const hb_buffer_flags_t
-
const hb_buffer_flags_t(64) - HB_BUFFER_FLAG_PRODUCE_SAFE_TO_INSERT_TATWEEL → const hb_buffer_flags_t
-
const hb_buffer_flags_t(128) - HB_BUFFER_FLAG_DEFINED → const hb_buffer_flags_t
-
const hb_buffer_flags_t(255)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → hb_buffer_flags_t
Constants
-
values
→ const List<
hb_buffer_flags_t> - A constant List of the values in this enum, in order of their declaration.