hb_buffer_serialize_flags_t enum
hb_buffer_serialize_flags_t: @HB_BUFFER_SERIALIZE_FLAG_DEFAULT: serialize glyph names, clusters and positions. @HB_BUFFER_SERIALIZE_FLAG_NO_CLUSTERS: do not serialize glyph cluster. @HB_BUFFER_SERIALIZE_FLAG_NO_POSITIONS: do not serialize glyph position information. @HB_BUFFER_SERIALIZE_FLAG_NO_GLYPH_NAMES: do no serialize glyph name. @HB_BUFFER_SERIALIZE_FLAG_GLYPH_EXTENTS: serialize glyph extents. @HB_BUFFER_SERIALIZE_FLAG_GLYPH_FLAGS: serialize glyph flags. Since: 1.5.0 @HB_BUFFER_SERIALIZE_FLAG_NO_ADVANCES: do not serialize glyph advances, glyph offsets will reflect absolute glyph positions. Since: 1.8.0. Note: when this flag is used with a partial range of the buffer (i.e. @start is not 0), calculating the absolute positions has a cost proportional to @start. If the buffer is serialized in many small chunks, this can lead to quadratic behavior. It is recommended to use a larger @buf_size to minimize this cost. @HB_BUFFER_SERIALIZE_FLAG_DEFINED: All currently defined flags. Since: 4.4.0
Flags that control what glyph information are serialized in hb_buffer_serialize_glyphs().
Since: 0.9.20
Values
- HB_BUFFER_SERIALIZE_FLAG_DEFAULT → const hb_buffer_serialize_flags_t
-
const hb_buffer_serialize_flags_t(0) - HB_BUFFER_SERIALIZE_FLAG_NO_CLUSTERS → const hb_buffer_serialize_flags_t
-
const hb_buffer_serialize_flags_t(1) - HB_BUFFER_SERIALIZE_FLAG_NO_POSITIONS → const hb_buffer_serialize_flags_t
-
const hb_buffer_serialize_flags_t(2) - HB_BUFFER_SERIALIZE_FLAG_NO_GLYPH_NAMES → const hb_buffer_serialize_flags_t
-
const hb_buffer_serialize_flags_t(4) - HB_BUFFER_SERIALIZE_FLAG_GLYPH_EXTENTS → const hb_buffer_serialize_flags_t
-
const hb_buffer_serialize_flags_t(8) - HB_BUFFER_SERIALIZE_FLAG_GLYPH_FLAGS → const hb_buffer_serialize_flags_t
-
const hb_buffer_serialize_flags_t(16) - HB_BUFFER_SERIALIZE_FLAG_NO_ADVANCES → const hb_buffer_serialize_flags_t
-
const hb_buffer_serialize_flags_t(32) - HB_BUFFER_SERIALIZE_FLAG_DEFINED → const hb_buffer_serialize_flags_t
-
const hb_buffer_serialize_flags_t(63)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → hb_buffer_serialize_flags_t
Constants
-
values
→ const List<
hb_buffer_serialize_flags_t> - A constant List of the values in this enum, in order of their declaration.