hb_buffer_serialize_format_t enum

hb_buffer_serialize_format_t: @HB_BUFFER_SERIALIZE_FORMAT_TEXT: a human-readable, plain text format. @HB_BUFFER_SERIALIZE_FORMAT_JSON: a machine-readable JSON format. @HB_BUFFER_SERIALIZE_FORMAT_INVALID: invalid format.

The buffer serialization and de-serialization format used in hb_buffer_serialize_glyphs() and hb_buffer_deserialize_glyphs().

Since: 0.9.2

Inheritance
Available extensions

Values

HB_BUFFER_SERIALIZE_FORMAT_TEXT → const hb_buffer_serialize_format_t
const hb_buffer_serialize_format_t(1413830740)
HB_BUFFER_SERIALIZE_FORMAT_JSON → const hb_buffer_serialize_format_t
const hb_buffer_serialize_format_t(1246973774)
HB_BUFFER_SERIALIZE_FORMAT_INVALID → const hb_buffer_serialize_format_t
const hb_buffer_serialize_format_t(0)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) hb_buffer_serialize_format_t

Constants

values → const List<hb_buffer_serialize_format_t>
A constant List of the values in this enum, in order of their declaration.