hb_reference_table_func_t typedef
hb_reference_table_func_t: @face: an #hb_face_t to reference table for @tag: the tag of the table to reference @user_data: User data pointer passed by the caller
Callback function for hb_face_create_for_tables(). The @tag is the tag of the table to reference, and the special tag #HB_TAG_NONE is used to reference the blob of the face itself. If referencing the face blob is not possible, it is recommended to set hb_get_table_tags_func_t on the @face to allow hb_face_reference_blob() to create a face blob out of individual table blobs.
Return value: (transfer full): A pointer to the @tag table within @face or
NULL if the table is not found or cannot be referenced.
Since: 0.9.2
Implementation
typedef hb_reference_table_func_t =
ffi.Pointer<ffi.NativeFunction<hb_reference_table_func_tFunction>>;