hb_subset_sets_t enum
hb_subset_sets_t: @HB_SUBSET_SETS_GLYPH_INDEX: the set of glyph indexes to retain in the subset. @HB_SUBSET_SETS_UNICODE: the set of unicode codepoints to retain in the subset. @HB_SUBSET_SETS_NO_SUBSET_TABLE_TAG: the set of table tags which specifies tables that should not be subsetted. @HB_SUBSET_SETS_DROP_TABLE_TAG: the set of table tags which specifies tables which will be dropped in the subset. @HB_SUBSET_SETS_NAME_ID: the set of name ids that will be retained. @HB_SUBSET_SETS_NAME_LANG_ID: the set of name lang ids that will be retained. @HB_SUBSET_SETS_LAYOUT_FEATURE_TAG: the set of layout feature tags that will be retained in the subset. @HB_SUBSET_SETS_LAYOUT_SCRIPT_TAG: the set of layout script tags that will be retained in the subset. Defaults to all tags. Since: 5.0.0
List of sets that can be configured on the subset input.
Since: 2.9.1
Values
- HB_SUBSET_SETS_GLYPH_INDEX → const hb_subset_sets_t
-
const hb_subset_sets_t(0) - HB_SUBSET_SETS_UNICODE → const hb_subset_sets_t
-
const hb_subset_sets_t(1) - HB_SUBSET_SETS_NO_SUBSET_TABLE_TAG → const hb_subset_sets_t
-
const hb_subset_sets_t(2) - HB_SUBSET_SETS_DROP_TABLE_TAG → const hb_subset_sets_t
-
const hb_subset_sets_t(3) - HB_SUBSET_SETS_NAME_ID → const hb_subset_sets_t
-
const hb_subset_sets_t(4) - HB_SUBSET_SETS_NAME_LANG_ID → const hb_subset_sets_t
-
const hb_subset_sets_t(5) - HB_SUBSET_SETS_LAYOUT_FEATURE_TAG → const hb_subset_sets_t
-
const hb_subset_sets_t(6) - HB_SUBSET_SETS_LAYOUT_SCRIPT_TAG → const hb_subset_sets_t
-
const hb_subset_sets_t(7)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → hb_subset_sets_t
Constants
-
values
→ const List<
hb_subset_sets_t> - A constant List of the values in this enum, in order of their declaration.