hb_variation_t class final
hb_variation_t: @tag: The #hb_tag_t tag of the variation-axis name @value: The value of the variation axis
Data type for holding variation data. Registered OpenType variation-axis tags are listed in OpenType Axis Tag Registry.
Since: 1.4.2
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited